@@ -1,7 +1,7 @@
 package App::GoogleAuthUtils;
 
 our $DATE = '2018-04-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -47,6 +47,8 @@ _
                 secret_key => '6XDT6TSOGR5SCWKHXZ4DFBRXJVZGAKAW',
                 issuer => 'example.com',
             },
+            test => 0,
+            'x.doc.show_result' => 0,
         },
     ],
 };
@@ -106,7 +108,7 @@ App::GoogleAuthUtils - Utilities related to Google Authenticator
 
 =head1 VERSION
 
-This document describes version 0.002 of App::GoogleAuthUtils (from Perl distribution App-GoogleAuthUtils), released on 2018-04-14.
+This document describes version 0.003 of App::GoogleAuthUtils (from Perl distribution App-GoogleAuthUtils), released on 2018-04-14.
 
 =head1 DESCRIPTION
 
@@ -140,10 +142,6 @@ Examples:
    issuer => "example.com"
  );
 
-Result:
-
- undef
-
 =back
 
 When generating a new 2FA token, you are usually presented with a secret key as
